@@ -34,6 +34,7 @@
 #include <KoFindText.h>
 #include <KoCanvasBase.h>
 #include <KoShapeManager.h>
+#include <KoPart.h>
 
 #include <KMimeType>
 #include <KMimeTypeTrader>
@@ -79,22 +80,27 @@ QStringList CATextDocumentHandler::supportedMimetypes()
     return supportedTypes;
 }
 
+KoZoomMode::Mode CATextDocumentHandler::preferredZoomMode() const
+{
+    return KoZoomMode::ZOOM_WIDTH;
+}
+
 bool CATextDocumentHandler::openDocument (const QString& uri)
 {
     QString error;
     QString mimetype = KMimeType::findByPath (uri)->name();
-    KoDocument* doc = KMimeTypeTrader::createInstanceFromQuery<KoDocument> (mimetype, QLatin1String("CalligraPart"), 0, QString(),
-                      QVariantList(), &error);
+    KoPart *part = KMimeTypeTrader::createInstanceFromQuery<KoPart>(mimetype,
+                      QLatin1String("CalligraPart"), 0, QString(), QVariantList(), &error);
 
-    if (!doc) {
+    if (!part) {
         kDebug() << "Doc can't be openend" << error;
         return false;
     }
 
-    d->document = static_cast<KWDocument*> (doc);
+    d->document = static_cast<KWDocument*> (part->document());
     d->document->openUrl (KUrl (uri));
 
-    setCanvas (dynamic_cast<KoCanvasBase*> (doc->canvasItem()));
+    setCanvas (dynamic_cast<KoCanvasBase*> (part->canvasItem()));
     KoToolManager::instance()->addController (dynamic_cast<KoCanvasController*> (documentController()->canvasController()));
     KoSelection *sel = canvas()->shapeManager()->selection();
 
@@ -118,23 +124,19 @@ bool CATextDocumentHandler::openDocument (const QString& uri)
 
     KoZoomHandler* zoomHandler = static_cast<KoZoomHandler*> (kwCanvasItem->viewConverter());
     documentController()->canvasController()->setZoomHandler (zoomHandler);
-    KoZoomController* zoomController =
-        new KoZoomController (dynamic_cast<KoCanvasController*> (documentController()->canvasController()),
-                              zoomHandler, doc->actionCollection());
-    documentController()->canvasController()->setZoomController (zoomController);
+    KoZoomController* zoomController = documentController()->canvasController()->zoomController();
     d->currentTextDocPage = d->document->pageManager()->begin();
     zoomController->setPageSize (d->currentTextDocPage.rect().size());
     zoomController->setZoom (KoZoomMode::ZOOM_CONSTANT, 1.0);
 
     if (kwCanvasItem) {
-        kwCanvasItem->updateSize();
-
         // whenever the size of the document viewed in the canvas changes, inform the zoom controller
         connect (kwCanvasItem, SIGNAL (documentSize (QSizeF)), zoomController, SLOT (setDocumentSize (QSizeF)));
         // update the canvas whenever we scroll, the canvas controller must emit this signal on scrolling/panning
         connect (documentController()->canvasController()->canvasControllerProxyObject(), SIGNAL (moveDocumentOffset (const QPoint&)),
                  kwCanvasItem, SLOT (setDocumentOffset (QPoint)));
         kwCanvasItem->updateSize();
+        kDebug() << "HANDLEEEE " << kwCanvasItem->geometry();
     }
 
     connect (documentController()->canvasController(), SIGNAL (needsCanvasResize (QSizeF)), SLOT (resizeCanvas (QSizeF)));
@@ -146,7 +148,7 @@ bool CATextDocumentHandler::openDocument (const QString& uri)
     KoFindText::findTextInShapes(kwCanvasItem->shapeManager()->shapes(), texts);
     d->findText->setDocuments(texts);
 
-    KAction *action = doc->actionCollection()->addAction(KStandardAction::Copy,  "edit_copy", 0, 0);
+    KAction *action = part->actionCollection()->addAction(KStandardAction::Copy,  "edit_copy", 0, 0);
     new KoCopyController(canvas(), action);
 
     return true;
@@ -218,8 +220,11 @@ int CATextDocumentHandler::totalPages() const {
 
 void CATextDocumentHandler::gotoPage(int pageNumber)
 {
-     d->currentTextDocPage = d->document->pageManager()->page(pageNumber);
-     documentController()->canvasController()->ensureVisible(d->currentTextDocPage.rect(), true);
+    if (pageNumber == d->currentTextDocPage.pageNumber())
+        return;
+    d->currentTextDocPage = d->document->pageManager()->page(pageNumber);
+    QRectF rect = documentController()->canvasController()->zoomHandler()->documentToView(d->currentTextDocPage.rect());
+    documentController()->canvasController()->alignTopWith(rect.top());
 }
 
 void CATextDocumentHandler::findNoMatchFound()
@@ -244,7 +249,12 @@ QString CATextDocumentHandler::leftToolbarSource() const
 
 void CATextDocumentHandler::copy()
 {
-    document()->actionCollection()->action("edit_copy")->activate(QAction::Trigger);
+    document()->documentPart()->actionCollection()->action("edit_copy")->activate(QAction::Trigger);
+}
+
+CAAbstractDocumentHandler::FlickModes CATextDocumentHandler::flickMode() const
+{
+    return FlickVertically;
 }
 
 #include "CATextDocumentHandler.moc"
