@@ -23,8 +23,14 @@
 #include "CACanvasController.h"
 #include "CADocumentInfo.h"
 #include "CADocumentController.h"
+#include "CACanvasItem.h"
+#include "CAPADocumentModel.h"
+#include "CAImageProvider.h"
+#include "CAAbstractDocumentHandler.h"
 #include "calligra_active_global.h"
 
+#include <libs/main/calligraversion.h>
+
 #include <KDE/KGlobal>
 #include <KDE/KStandardDirs>
 #include <KDE/KDebug>
@@ -42,7 +48,10 @@ MainWindow::MainWindow (QWidget* parent)
     qmlRegisterType<CACanvasController> ("CalligraActive", 1, 0, "CanvasController");
     qmlRegisterType<CADocumentInfo> ("CalligraActive", 1, 0, "CADocumentInfo");
     qmlRegisterType<CADocumentController> ("CalligraActive", 1, 0, "CADocumentController");
+    qmlRegisterType<CACanvasItem> ("CalligraActive", 1, 0, "CACanvasItem");
+    qmlRegisterType<CAPADocumentModel> ("CalligraActive", 1, 0, "CAPADocumentModel");
     qmlRegisterInterface<KoCanvasController> ("KoCanvasController");
+    qmlRegisterUncreatableType<CAAbstractDocumentHandler>("CalligraActive", 1, 0, "CAAbstractDocumentHandler", "Not allowed");
 
     m_view = new QDeclarativeView (this);
 
@@ -76,17 +85,15 @@ MainWindow::MainWindow (QWidget* parent)
     }
 
     m_view->rootContext()->setContextProperty ("mainwindow", this);
+    m_view->rootContext()->setContextProperty("_calligra_version_string", CALLIGRA_VERSION_STRING);
+    m_view->engine()->addImageProvider(CAImageProvider::identificationString, CAImageProvider::instance());
     loadMetadataModel();
 
     m_view->setSource (QUrl::fromLocalFile (CalligraActive::Global::installPrefix()
                                             + "/share/calligraactive/qml/HomeScreen.qml"));
     m_view->setResizeMode (QDeclarativeView::SizeRootObjectToView);
 
-    setCentralWidget (m_view);
-    connect (m_view, SIGNAL (sceneResized (QSize)), SLOT (adjustWindowSize (QSize)));
-    resize (800, 600);
-
-    QTimer::singleShot(1000, this, SLOT(checkForAndOpenDocument()));
+    QTimer::singleShot(0, this, SLOT(checkForAndOpenDocument()));
 }
 
 void MainWindow::openFile (const QString& path)
@@ -132,12 +139,14 @@ MainWindow::~MainWindow()
 
 void MainWindow::checkForAndOpenDocument()
 {
-    if (documentPath.isEmpty()) {
-        return;
+    if (!documentPath.isEmpty()) {
+        QObject* object = m_view->rootObject();
+        QMetaObject::invokeMethod (object, "openDocument", Q_ARG (QVariant, QVariant (documentPath)));
     }
 
-    QObject* object = m_view->rootObject();
-    QMetaObject::invokeMethod (object, "openDocument", Q_ARG (QVariant, QVariant (documentPath)));
+    connect (m_view, SIGNAL (sceneResized (QSize)), SLOT (adjustWindowSize (QSize)));
+    resize (1024, 768);
+    setCentralWidget (m_view);
 }
 
 #include "MainWindow.moc"
