@@ -24,8 +24,8 @@
 #include "kexiproject.h"
 #include <koproperty/Set.h>
 
-#include <kexidb/connection.h>
-#include <kexidb/utils.h>
+#include <db/connection.h>
+#include <db/utils.h>
 #include <kexiutils/utils.h>
 #include <kexiutils/SmallToolButton.h>
 #include <kexiutils/FlowLayout.h>
@@ -678,4 +678,9 @@ void KexiView::setSortedProperties(bool set)
     d->sortedProperties = set;
 }
 
+bool KexiView::saveSettings()
+{
+    return true;
+}
+
 #include "KexiView.moc"
