@@ -22,7 +22,6 @@
 #include <KexiSearchableModel.h>
 
 #include <KLocale>
-#include <KIcon>
 #include <KDebug>
 
 #include <kexiutils/completer/KexiCompleter.h>
@@ -507,9 +506,7 @@ void KexiSearchLineEdit::focusOutEvent(QFocusEvent *e)
     update();
     if (e->reason() == Qt::TabFocusReason || e->reason() == Qt::BacktabFocusReason) {
         // go back to previously focused widget
-        if (d->previouslyFocusedWidget) {
-            d->previouslyFocusedWidget->setFocus();
-        }
+        d->previouslyFocusedWidget->setFocus();
         e->accept();
     }
     d->previouslyFocusedWidget = 0;
