@@ -60,11 +60,12 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kglobalsettings.h>
-#include <kiconloader.h>
 #include <kcharsets.h>
 #include <knuminput.h>
 #include <KProgressDialog>
 
+#include <KoIcon.h>
+
 #include <kexiutils/identifier.h>
 #include <kexiutils/utils.h>
 #include <core/kexi.h>
@@ -73,15 +74,15 @@
 #include <core/kexipartinfo.h>
 #include <core/KexiMainWindowIface.h>
 #include <core/kexiguimsghandler.h>
-#include <kexidb/connection.h>
-#include <kexidb/tableschema.h>
-#include <kexidb/transaction.h>
+#include <db/connection.h>
+#include <db/tableschema.h>
+#include <db/transaction.h>
 #include <widget/kexicharencodingcombobox.h>
 
 #include "kexicsvwidgets.h"
 #include <kexi_global.h>
 
-#define _IMPORT_ICON KIcon("table") /*todo: change to "file_import" or so*/
+#define _IMPORT_ICON koIconNeededWithSubs("change to file_import or so", "file_import","table")
 
 //! @internal
 class KexiCSVImportStatic
@@ -314,7 +315,7 @@ KexiCSVImportDialog::KexiCSVImportDialog(Mode mode, QWidget * parent)
     m_minimumYearFor100YearSlidingWindow = importExportGroup.readEntry(
         "MinimumYearFor100YearSlidingWindow", MINIMUM_YEAR_FOR_100_YEAR_SLIDING_WINDOW);
 
-    m_pkIcon = SmallIcon("key");
+    m_pkIcon = koSmallIcon("key");
 
 // m_encoding = QString::fromLatin1(KGlobal::locale()->encoding());
 // m_trimmedInTextValuesChecked = true;
@@ -507,7 +508,7 @@ KexiCSVImportDialog::KexiCSVImportDialog(Mode mode, QWidget * parent)
     }
 
     if (m_mode == Clipboard) {
-        m_infoLbl->setIcon("edit-paste");
+        m_infoLbl->setIcon(koIconName("edit-paste"));
     }
     //updateRowCountInfo();
 
@@ -1558,7 +1559,7 @@ void KexiCSVImportDialog::accept()
                      "Should it be automatically defined on import (recommended)?\n\n"
                      "Note: An imported table without a Primary Key may not be editable (depending on database type)."),
                 QString(),
-                KGuiItem(i18nc("Add Database Primary Key to a Table", "Add Primary Key"), "key"),
+                KGuiItem(i18nc("Add Database Primary Key to a Table", "Add Primary Key"), koIconName("key")),
                 KGuiItem(i18nc("Do Not Add Database Primary Key to a Table", "Do Not Add")))))
     {
         if (msgboxResult == KMessageBox::Cancel) {
@@ -1720,7 +1721,7 @@ void KexiCSVImportDialog::accept()
     msgboxResult = KMessageBox::questionYesNo(this,
                        i18n("Data has been successfully imported to table \"%1\".",
                             m_destinationTableSchema->name()),
-//! @todo 2.5 add title "Successfull import"
+//! @todo 2.5 add title "Successful import"
                        QString(),
 //! @todo 2.5 change to "Open Imported Table"
                        KStandardGuiItem::open(),
