@@ -21,11 +21,11 @@
 
 #include <unistd.h>
 
-#include <qapplication.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qregexp.h>
-#include <qclipboard.h>
+#include <QApplication>
+#include <QFile>
+#include <QDir>
+#include <QRegExp>
+#include <QClipboard>
 
 #include <kdebug.h>
 
@@ -37,8 +37,8 @@
 #include <core/kexitabledesignerinterface.h>
 #include <core/kexiinternalpart.h>
 #include <kexiutils/utils.h>
-#include <kexidb/connection.h>
-#include <kexidb/utils.h>
+#include <db/connection.h>
+#include <db/utils.h>
 
 QString testFilename;
 QFile testFile;
