@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2012 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2005 Jarosław Staniek <staniek@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,9 @@
 #include <QList>
 #include <QByteArray>
 #include <koproperty/Set.h>
-#include <kexidb/RecordData.h>
+#include <db/RecordData.h>
+
+typedef QVector<KoProperty::Set*> SetVector;
 
 class KexiView;
 class KexiTableViewData;
@@ -72,13 +74,13 @@ public:
     uint currentRow() const;
 
     inline KoProperty::Set* at(uint row) const {
-        return m_sets.value(row);
+        return m_sets[row];
     }
 
     /*! \return a pointer to property set assigned for \a record or null if \a item has no
      property set assigned or it's not owned by assigned table view or
      if assigned table view has no data set. */
-    KoProperty::Set* findPropertySetForItem(const KexiDB::RecordData& record);
+    KoProperty::Set* findPropertySetForItem(KexiDB::RecordData& record);
 
     /*! \return number of the first row containing \a propertyName property equal to \a value.
      This is used e.g. in the Table Designer to find a row by field name.
@@ -99,7 +101,7 @@ signals:
 public slots:
     void eraseCurrentPropertySet();
 
-    void clear();
+    void clear(uint minimumSize = 0);
 
     /*! Inserts \a set property set at \a row position.
      If there was a buffer at this position before, it will be destroyed.
@@ -115,7 +117,7 @@ public slots:
     */
     void set(uint row, KoProperty::Set* set, bool newOne = false);
 
-    /*! Deletes a property set at \a row position without removing the row. */
+    /*! Erases a property set at \a row position. */
     void eraseAt(uint row);
 
 protected slots:
@@ -138,9 +140,7 @@ protected slots:
     void slotReloadRequested();
 
 protected:
-    void enlargeToFitRow(uint row);
-
-    QVector<KoProperty::Set*> m_sets; //!< prop. sets vector
+    SetVector m_sets; //!< prop. sets vector
 
     QPointer<KexiView> m_view;
     KexiDataAwareObjectInterface* m_dataObject;
