@@ -27,6 +27,7 @@
 #include <QVector>
 
 #include <KoColorSpaceConstants.h>
+#include <KoColorConversionTransformation.h>
 
 #include "kis_distance_information.h"
 #include "kis_global.h"
@@ -152,7 +153,6 @@ public:
      *
      * @param dstX the destination x-coordinate
      * @param dstY the destination y-coordinate
-     * @param op a pointer to the composite op used to blast the pixels from @param srcDev to the current paint device
      * @param srcDev the source device
      * @param srcX the source x-coordinate
      * @param srcY the source y-coordinate
@@ -176,16 +176,10 @@ public:
     void bitBlt(const QPoint & pos, const KisPaintDeviceSP srcDev, const QRect & srcRect);
 
     /**
-     * Blast a region of srcWidth @param srcWidth and srcHeight @param srcHeight from @param
-     * srcDev onto the current paint device. @param srcX and @param srcY set the x and y
-     * positions of the origin top-left corner, @param dstX and @param dstY those of
-     * the destination.
-     * Any pixel read outside the limits of @param srcDev will return the
-     * default pixel, this is a property of \ref KisPaintDevice.
+     * The same as @ref bitBlt() but reads data from oldData() part of the device
      *
      * @param dstX the destination x-coordinate
      * @param dstY the destination y-coordinate
-     * @param op a pointer to the composite op used to blast the pixels from @param srcDev to the current paint device
      * @param srcDev the source device
      * @param srcX the source x-coordinate
      * @param srcY the source y-coordinate
@@ -193,9 +187,9 @@ public:
      * @param srcHeight the height of the region to be manipulated
      */
     void bitBltOldData(qint32 dstX, qint32 dstY,
-                const KisPaintDeviceSP srcDev,
-                qint32 srcX, qint32 srcY,
-                qint32 srcWidth, qint32 srcHeight);
+                       const KisPaintDeviceSP srcDev,
+                       qint32 srcX, qint32 srcY,
+                       qint32 srcWidth, qint32 srcHeight);
 
     /**
      * Convenience method that uses QPoint and QRect.
@@ -268,7 +262,6 @@ public:
      *
      * @param dstX the destination x-coordinate
      * @param dstY the destination y-coordinate
-     * @param op a pointer to the composite op use to blast the pixels from srcDev on dst
      * @param srcDev the source device
      * @param srcX the source x-coordinate
      * @param srcY the source y-coordinate
@@ -310,7 +303,6 @@ public:
      *
      * @param dstX the destination x-coordinate
      * @param dstY the destination y-coordinate
-     * @param op a pointer to the composite op use to blast the pixels from srcDev on dst
      * @param srcDev the source device
      * @param selection the selection stored in fixed device
      * @param selX the selection x-coordinate
@@ -371,6 +363,17 @@ public:
     void renderMirrorMask(QRect rc, KisPaintDeviceSP dab, KisFixedPaintDeviceSP mask);
     void renderMirrorMask(QRect rc, KisPaintDeviceSP dab, int sx, int sy, KisFixedPaintDeviceSP mask);
 
+    /**
+     * Convinience method for renderMirrorMask(), allows to choose whether
+     * we need to preserve out dab or do the transformations in-place.
+     *
+     * @param rc rectangle area covered by dab
+     * @param dab the device to render
+     * @param preserveDab states whether a temporary device should be
+     *                    created to do the transformations
+     */
+    void renderMirrorMaskSafe(QRect rc, KisFixedPaintDeviceSP dab, bool preserveDab);
+
     /**
      * Special method for some paintop that needs to know which areas where covered by the dab
      * E.g. experimental (shape) paintop needs to know it to be able to copy appriate regions from
@@ -703,6 +706,17 @@ public:
     void setLockAlpha(bool protect);
     bool alphaLocked() const;
 
+
+    /**
+     * set the rendering intent in case pixels need to be converted before painting
+     */
+    void setRenderingIntent(KoColorConversionTransformation::Intent intent);
+
+    /**
+     * set the conversion flags in case pixels need to be converted before painting
+     */
+    void setColorConversionFlags(KoColorConversionTransformation::ConversionFlags conversionFlags);
+
 protected:
     /// Initialize, set everything to '0' or defaults
     void init();
@@ -728,6 +742,13 @@ private:
 protected:
     KoUpdater * progressUpdater();
 
+private:
+    template <bool useOldSrcData>
+        void bitBltImpl(qint32 dstX, qint32 dstY,
+                        const KisPaintDeviceSP srcDev,
+                        qint32 srcX, qint32 srcY,
+                        qint32 srcWidth, qint32 srcHeight);
+
 private:
 
     struct Private;
