@@ -42,7 +42,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 #endif
 
     int state;
-    KAboutData * aboutData = newKritaAboutData();
+    KAboutData *aboutData = newKritaAboutData();
 
     KCmdLineArgs::init(argc, argv, aboutData);
 
@@ -56,15 +56,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
     // then create the pixmap from an xpm: we cannot get the
     // location of our datadir before we've started our components,
     // so use an xpm.
-    QPixmap pm;
-    int i = random() % 3;
-    if (i < 1) {
-        pm = QPixmap(tear);
-    }
-    else {
-        pm = QPixmap(notear);
-    }
-    
+    QPixmap pm(splash_screen_xpm);
     QSplashScreen *splash = new KSplashScreen(pm);
     app.setSplashScreen(splash);
 
