@@ -25,6 +25,7 @@
 #include <QSize>
 #include <QString>
 
+#include <KoColorSpace.h>
 #include <KoCanvasBase.h>
 #include <krita_export.h>
 #include <kis_types.h>
@@ -40,6 +41,7 @@ class KisCanvasDecoration;
 class KisView2;
 class KisPaintopBox;
 class KoFavoriteResourceManager;
+class KisDisplayFilter;
 
 enum KisCanvasType {
     QPAINTER,
@@ -141,7 +143,6 @@ public: // KisCanvas2 methods
     KisImageWSP image();
     KisView2* view();
 
-    bool usingHDRExposureProgram();
     /// @return true if the canvas image should be displayed in vertically mirrored mode
     void addDecoration(KisCanvasDecoration* deco);
     KisCanvasDecoration* decoration(const QString& id);
@@ -166,6 +167,16 @@ public slots:
     void startUpdateCanvasProjection(const QRect & rc);
     void updateCanvasProjection(KisUpdateInfoSP info);
 
+    void startUpdateInPatches(QRect imageRect);
+
+    void setMonitorProfile(KoColorProfile* monitorProfile,
+                           KoColorConversionTransformation::Intent renderingIntent,
+                           KoColorConversionTransformation::ConversionFlags conversionFlags);
+
+
+
+    void setDisplayFilter(KisDisplayFilter *displayFilter);
+
     void startResizingImage(qint32 w, qint32 h);
     void finishResizingImage(qint32 w, qint32 h);
 
@@ -210,7 +221,7 @@ public:
     bool handlePopupPaletteIsVisible();
 
 private:
-    Q_DISABLE_COPY(KisCanvas2);
+    Q_DISABLE_COPY(KisCanvas2)
 
     void pan(QPoint shift);
     void createCanvas(bool useOpenGL);
