@@ -22,6 +22,8 @@
 #include <QCursor>
 #include <QString>
 #include <QDialog>
+#include <QVBoxLayout>
+#include <QFileInfo>
 
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
@@ -29,8 +31,12 @@
 #include <kstandardaction.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
+#include <kfilewidget.h>
 #include <kurl.h>
+#include <kdiroperator.h>
+#include <kurlcombobox.h>
 
+#include <KoIcon.h>
 #include <KoFilterManager.h>
 #include <KoDocument.h>
 #include <KoColorSpace.h>
@@ -63,6 +69,7 @@
 #include <metadata/kis_meta_data_store.h>
 #include <metadata/kis_meta_data_merge_strategy_registry.h>
 
+#include "kis_part2.h"
 #include "kis_config.h"
 #include "kis_cursor.h"
 #include "dialogs/kis_dlg_adj_layer_props.h"
@@ -88,17 +95,151 @@
 #include "kis_mirror_visitor.h"
 
 
+class KisSaveGroupVisitor : public KisNodeVisitor
+{
+public:
+    KisSaveGroupVisitor(KisView2 *view,
+                        KisImageWSP image,
+                        bool saveInvisible,
+                        bool saveTopLevelOnly,
+                        const KUrl &url,
+                        const QString &baseName,
+                        const QString &extension,
+                        const QString &mimeFilter)
+        : m_view(view)
+        , m_image(image)
+        , m_saveInvisible(saveInvisible)
+        , m_saveTopLevelOnly(saveTopLevelOnly)
+        , m_url(url)
+        , m_baseName(baseName)
+        , m_extension(extension)
+        , m_mimeFilter(mimeFilter)
+    {
+    }
+
+    virtual ~KisSaveGroupVisitor()
+    {
+    }
+
+public:
+
+    bool visit(KisNode* ) {
+        return true;
+    }
+
+    bool visit(KisPaintLayer *) {
+        return true;
+    }
+
+    bool visit(KisAdjustmentLayer *) {
+        return true;
+    }
+
+
+    bool visit(KisExternalLayer *) {
+        return true;
+    }
+
+
+    bool visit(KisCloneLayer *) {
+        return true;
+    }
+
+
+    bool visit(KisFilterMask *) {
+        return true;
+    }
+
+
+    bool visit(KisTransparencyMask *) {
+        return true;
+    }
+
+
+    bool visit(KisGeneratorLayer * ) {
+        return true;
+    }
+
+    bool visit(KisSelectionMask* ) {
+        return true;
+    }
+
+    bool visit(KisGroupLayer *layer)
+    {
+        if (layer == m_image->rootLayer()) {
+            KisLayerSP child = dynamic_cast<KisLayer*>(layer->firstChild().data());
+            while (child) {
+                child->accept(*this);
+                child = dynamic_cast<KisLayer*>(child->nextSibling().data());
+            }
+
+        }
+        else if (layer->visible() || m_saveInvisible) {
+
+            QRect r = m_image->bounds();
+
+            KisPart2 *p = new KisPart2();
+            KisDoc2 d(p);
+            p->setDocument(&d);
+            d.prepareForImport();
+
+            KisImageWSP dst = new KisImage(d.createUndoStore(), r.width(), r.height(), m_image->colorSpace(), layer->name());
+            dst->setResolution(m_image->xRes(), m_image->yRes());
+            d.setCurrentImage(dst);
+            KisPaintLayer* paintLayer = new KisPaintLayer(dst, "projection", layer->opacity());
+            KisPainter gc(paintLayer->paintDevice());
+            gc.bitBlt(QPoint(0, 0), layer->projection(), r);
+            dst->addNode(paintLayer, dst->rootLayer(), KisLayerSP(0));
+
+            dst->refreshGraph();
+
+            d.setOutputMimeType(m_mimeFilter.toLatin1());
+            d.setSaveInBatchMode(true);
+
+
+            KUrl url = m_url;
+            url.adjustPath(KUrl::AddTrailingSlash);
+
+            url.setFileName(m_baseName + "_" + layer->name().replace(" ", "_") + "." + m_extension);
+
+            d.exportDocument(url);
+
+            if (!m_saveTopLevelOnly) {
+                KisGroupLayerSP child = dynamic_cast<KisGroupLayer*>(layer->firstChild().data());
+                while (child) {
+                    child->accept(*this);
+                    child = dynamic_cast<KisGroupLayer*>(child->nextSibling().data());
+                }
+            }
+        }
+        return true;
+    }
+
+private:
+
+    KisView2 *m_view;
+    KisImageWSP m_image;
+    bool m_saveInvisible;
+    bool m_saveTopLevelOnly;
+    KUrl m_url;
+    QString m_baseName;
+    QString m_extension;
+    QString m_mimeFilter;
+};
+
+
+
 KisLayerManager::KisLayerManager(KisView2 * view, KisDoc2 * doc)
     : m_view(view)
     , m_doc(doc)
     , m_imageFlatten(0)
     , m_imageMergeLayer(0)
     , m_layerSaveAs(0)
+    , m_groupLayersSave(0)
     , m_actLayerVis(false)
     , m_imageResizeToLayer(0)
     , m_flattenLayer(0)
     , m_rasterizeLayer(0)
-    , m_duplicateLayer(0)
     , m_addPaintLayer(0)
     , m_activeLayer(0)
     , m_commandsAdapter(new KisNodeCommandsAdapter(m_view))
@@ -154,19 +295,18 @@ void KisLayerManager::setup(KActionCollection * actionCollection)
     actionCollection->addAction("rasterize_layer", m_rasterizeLayer);
     connect(m_rasterizeLayer, SIGNAL(triggered()), this, SLOT(rasterizeLayer()));
 
-    m_layerSaveAs  = new KAction(KIcon("document-save"), i18n("Save Layer as Image..."), this);
+    m_layerSaveAs  = new KAction(koIcon("document-save"), i18n("Save Layer as Image..."), this);
     actionCollection->addAction("save_layer_as_image", m_layerSaveAs);
     connect(m_layerSaveAs, SIGNAL(triggered()), this, SLOT(saveLayerAsImage()));
 
+    m_groupLayersSave = new KAction(koIcon("document-save"), i18n("Save Group Layers..."), this);
+    actionCollection->addAction("save_groups_as_images", m_groupLayersSave);
+    connect(m_groupLayersSave, SIGNAL(triggered()), this, SLOT(saveGroupLayers()));
+
     m_imageResizeToLayer  = new KAction(i18n("Size Canvas to Size of Current Layer"), this);
     actionCollection->addAction("resizeimagetolayer", m_imageResizeToLayer);
     connect(m_imageResizeToLayer, SIGNAL(triggered()), this, SLOT(imageResizeToActiveLayer()));
 
-    m_duplicateLayer = new KAction(i18n("Duplicate current layer"), this);
-    m_duplicateLayer->setShortcut(KShortcut(Qt::ControlModifier + Qt::Key_J));
-    actionCollection->addAction("duplicatelayer", m_duplicateLayer);
-    connect(m_duplicateLayer, SIGNAL(triggered()), this, SLOT(layerDuplicate()));
-
     m_addPaintLayer = new KAction(i18n("Add new paint layer"), this);
     m_addPaintLayer->setShortcut(KShortcut(Qt::Key_Insert));
     actionCollection->addAction("add_new_paint_layer", m_addPaintLayer);
@@ -496,28 +636,6 @@ void KisLayerManager::addGeneratorLayer(KisNodeSP parent, KisNodeSP above, const
     m_commandsAdapter->addNode(l.data(), parent, above.data());
 }
 
-
-void KisLayerManager::layerRemove()
-{
-    KisImageWSP image = m_view->image();
-
-    if (image) {
-        KisLayerSP layer = activeLayer();
-        if (layer) {
-            QRect extent = layer->extent();
-            KisNodeSP parent = layer->parent();
-
-            m_commandsAdapter->removeNode(layer);
-
-            if (parent)
-                parent->setDirty(extent);
-
-            m_view->canvas()->update();
-            m_view->updateGUI();
-        }
-    }
-}
-
 void KisLayerManager::layerDuplicate()
 {
     KisImageWSP image = m_view->image();
@@ -767,7 +885,10 @@ void KisLayerManager::saveLayerAsImage()
 
     QRect r = image->bounds();
 
-    KisDoc2 d;
+    KisPart2 *p = new KisPart2();
+    KisDoc2 d(p);
+    p->setDocument(&d);
+
     d.prepareForImport();
 
     KisImageWSP dst = new KisImage(d.createUndoStore(), r.width(), r.height(), image->colorSpace(), l->name());
@@ -784,6 +905,58 @@ void KisLayerManager::saveLayerAsImage()
     d.exportDocument(url);
 }
 
+void KisLayerManager::saveGroupLayers()
+{
+    QStringList listMimeFilter = KoFilterManager::mimeFilter("application/x-krita", KoFilterManager::Export);
+
+    KDialog dlg;
+    QWidget *page = new QWidget(&dlg);
+    dlg.setMainWidget(page);
+    QBoxLayout *layout = new QVBoxLayout(page);
+
+    KFileWidget *fd = new KFileWidget(m_view->document()->url().path(), page);
+    fd->setUrl(m_view->document()->url());
+    fd->setMimeFilter(listMimeFilter);
+    fd->setOperationMode(KAbstractFileWidget::Saving);
+    layout->addWidget(fd);
+
+    QCheckBox *chkInvisible = new QCheckBox(i18n("Convert Invisible Groups"), page);
+    chkInvisible->setChecked(false);
+    layout->addWidget(chkInvisible);
+    QCheckBox *chkDepth = new QCheckBox(i18n("Export Only Toplevel Groups"), page);
+    chkDepth->setChecked(true);
+    layout->addWidget(chkDepth);
+
+    if (!dlg.exec()) return;
+
+    // selectedUrl()( does not return the expected result. So, build up the KUrl the more complicated way
+    //return m_fileWidget->selectedUrl();
+    KUrl url = fd->dirOperator()->url();
+    url.adjustPath(KUrl::AddTrailingSlash);
+    QString path = fd->locationEdit()->currentText();
+    QFileInfo f(path);
+    QString extension = f.completeSuffix();
+    QString basename = f.baseName();
+
+    QString mimefilter = fd->currentMimeFilter();
+
+    if (mimefilter.isEmpty()) {
+        KMimeType::Ptr mime = KMimeType::findByUrl(url);
+        mimefilter = mime->name();
+        extension = mime->extractKnownExtension(path);
+    }
+
+    if (url.isEmpty())
+        return;
+
+    KisImageWSP image = m_view->image();
+    if (!image) return;
+
+    KisSaveGroupVisitor v(m_view, image, chkInvisible->isChecked(), chkDepth->isChecked(), url, basename, extension, mimefilter);
+    image->rootLayer()->accept(v);
+
+}
+
 bool KisLayerManager::activeLayerHasSelection()
 {
     return (activeLayer()->selection() != 0);
