@@ -443,7 +443,7 @@ void KoTextEditor::addBookmark(const QString &name)
         return;
     }
 
-    d->updateState(KoTextEditor::Private::Custom, i18n("Insert Bookmark"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Insert Bookmark"));
     KoBookmark *bookmark = new KoBookmark(d->document);
     bookmark->setName(name);
     int startPos = -1, endPos = -1, caretPos = -1;
@@ -486,7 +486,7 @@ KoInlineObject *KoTextEditor::insertIndexMarker()
         return 0;
     }
 
-    d->updateState(KoTextEditor::Private::Custom, i18n("Insert Index"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Insert Index"));
 
     int startPosition = d->caret.position();
 
@@ -523,7 +523,7 @@ void KoTextEditor::insertInlineObject(KoInlineObject *inliner, KUndo2Command *cm
         return;
     }
 
-    d->updateState(KoTextEditor::Private::Custom, i18n("Insert Variable"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Insert Variable"));
 
     int startPosition = d->caret.position();
 
@@ -591,7 +591,12 @@ void KoTextEditor::insertFrameBreak()
         return;
     }
 
-    d->updateState(KoTextEditor::Private::KeyPress, i18n("Insert Break"));
+    QTextCursor curr(d->caret.block());
+    if (dynamic_cast<QTextTable *> (curr.currentFrame())) {
+        return;
+    }
+
+    d->updateState(KoTextEditor::Private::KeyPress, i18nc("(qtundo-format)", "Insert Break"));
     QTextBlock block = d->caret.block();
     if (d->caret.position() == block.position() && block.length() > 0) { // start of parag
         QTextBlockFormat bf = d->caret.blockFormat();
@@ -671,14 +676,12 @@ bool KoTextEditor::paste(KoTextEditor *editor,
         if (pasteAsText) {
             insertText(data->text());
         } else {
-            const Soprano::Model *rdfModel = 0;
+            QSharedPointer<Soprano::Model> rdfModel = QSharedPointer<Soprano::Model>(0);
 #ifdef SHOULD_BUILD_RDF
-            bool weOwnRdfModel = true;
-            rdfModel = Soprano::createModel();
-            if (rdf) {
-                delete rdfModel;
+            if(!rdf) {
+                rdfModel = QSharedPointer<Soprano::Model>(Soprano::createModel());
+            } else {
                 rdfModel = rdf->model();
-                weOwnRdfModel = false;
             }
 #endif
 
@@ -691,9 +694,6 @@ bool KoTextEditor::paste(KoTextEditor *editor,
             if (rdf) {
                 rdf->updateInlineRdfStatements(d->document);
             }
-            if (weOwnRdfModel && rdfModel) {
-                delete rdfModel;
-            }
 #endif
         }
     }
@@ -995,7 +995,7 @@ void KoTextEditor::insertTable(int rows, int columns)
     if (changeTracker && changeTracker->recordChanges()) {
         QTextCharFormat charFormat = d->caret.charFormat();
         QTextBlockFormat blockFormat = d->caret.blockFormat();
-        QString title = i18n("Insert Table");
+        QString title = i18nc("(qtundo-format)", "Insert Table");
 
         int changeId;
         if (!d->caret.atBlockStart()) {
@@ -1067,7 +1067,7 @@ void KoTextEditor::insertTableRowAbove()
         int changeId = 0;
         KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
         if (changeTracker && changeTracker->recordChanges()) {
-            QString title(i18n("Insert Row Above"));
+            QString title(i18nc("(qtundo-format)", "Insert Row Above"));
             changeId = changeTracker->getInsertChangeId(title, 0);
         }
         addCommand(new InsertTableRowCommand(this, table, false, changeId));
@@ -1085,7 +1085,7 @@ void KoTextEditor::insertTableRowBelow()
         int changeId = 0;
         KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
         if (changeTracker && changeTracker->recordChanges()) {
-            QString title(i18n("Insert Row Above"));
+            QString title(i18nc("(qtundo-format)", "Insert Row Above"));
             changeId = changeTracker->getInsertChangeId(title, 0);
         }
         addCommand(new InsertTableRowCommand(this, table, true, changeId));
@@ -1103,7 +1103,7 @@ void KoTextEditor::insertTableColumnLeft()
         int changeId = 0;
         KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
         if (changeTracker && changeTracker->recordChanges()) {
-            QString title(i18n("Insert Column Left"));
+            QString title(i18nc("(qtundo-format)", "Insert Column Left"));
             changeId = changeTracker->getInsertChangeId(title, 0);
         }
         addCommand(new InsertTableColumnCommand(this, table, false, changeId));
@@ -1121,7 +1121,7 @@ void KoTextEditor::insertTableColumnRight()
         int changeId = 0;
         KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
         if (changeTracker && changeTracker->recordChanges()) {
-            QString title(i18n("Insert Column Right"));
+            QString title(i18nc("(qtundo-format)", "Insert Column Right"));
             changeId = changeTracker->getInsertChangeId(title, 0);
         }
         addCommand(new InsertTableColumnCommand(this, table, true, changeId));
@@ -1139,7 +1139,7 @@ void KoTextEditor::deleteTableColumn()
         int changeId = 0;
         KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
         if (changeTracker && changeTracker->recordChanges()) {
-            QString title(i18n("Delete Column"));
+            QString title(i18nc("(qtundo-format)", "Delete Column"));
             changeId = changeTracker->getDeleteChangeId(title, QTextDocumentFragment(), 0);
         }
 
@@ -1158,7 +1158,7 @@ void KoTextEditor::deleteTableRow()
         KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
         int changeId = 0;
         if (changeTracker && changeTracker->recordChanges()) {
-            QString title(i18n("Delete Row"));
+            QString title(i18nc("(qtundo-format)", "Delete Row"));
             changeId = changeTracker->getDeleteChangeId(title, QTextDocumentFragment(), 0);
         }
         addCommand(new DeleteTableRowCommand(this, table, changeId));
@@ -1171,7 +1171,7 @@ void KoTextEditor::mergeTableCells()
         return;
     }
 
-    d->updateState(KoTextEditor::Private::Custom, i18n("Merge Cells"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Merge Cells"));
 
     QTextTable *table = d->caret.currentTable();
 
@@ -1188,7 +1188,7 @@ void KoTextEditor::splitTableCells()
         return;
     }
 
-    d->updateState(KoTextEditor::Private::Custom, i18n("Split Cells"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Split Cells"));
 
     QTextTable *table = d->caret.currentTable();
 
@@ -1217,7 +1217,7 @@ void KoTextEditor::adjustTableRowHeight(QTextTable *table, int column, qreal hei
 
 void KoTextEditor::adjustTableWidth(QTextTable *table, qreal dLeft, qreal dRight)
 {
-    d->updateState(KoTextEditor::Private::Custom, i18n("Adjust Table Width"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Adjust Table Width"));
     d->caret.beginEditBlock();
     QTextTableFormat fmt = table->format();
     if (dLeft) {
@@ -1234,7 +1234,7 @@ void KoTextEditor::adjustTableWidth(QTextTable *table, qreal dLeft, qreal dRight
 void KoTextEditor::setTableBorderData(QTextTable *table, int row, int column,
          KoBorder::Side cellSide, const KoBorder::BorderData &data)
 {
-    d->updateState(KoTextEditor::Private::Custom, i18n("Change Border Formatting"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Change Border Formatting"));
     d->caret.beginEditBlock();
     QTextTableCell cell = table->cellAt(row, column);
     QTextCharFormat fmt = cell.format();
@@ -1317,7 +1317,7 @@ void KoTextEditor::insertTableOfContents(KoTableOfContentsGeneratorInfo *info)
     if (changeTracker && changeTracker->recordChanges()) {
         QTextCharFormat charFormat = d->caret.charFormat();
         QTextBlockFormat blockFormat = d->caret.blockFormat();
-        QString title = i18n("Insert Table Of Contents");
+        QString title = i18nc("(qtundo-format)", "Insert Table Of Contents");
 
         int changeId;
         if (!d->caret.atBlockStart()) {
@@ -1356,7 +1356,7 @@ void KoTextEditor::setTableOfContentsConfig(KoTableOfContentsGeneratorInfo *info
 
     KoTableOfContentsGeneratorInfo *newToCInfo=info->clone();
 
-    d->updateState(KoTextEditor::Private::Custom, i18n("Modify Table Of Contents"));
+    d->updateState(KoTextEditor::Private::Custom, i18nc("(qtundo-format)", "Modify Table Of Contents"));
 
     QTextCursor cursor(block);
     QTextBlockFormat tocBlockFormat=block.blockFormat();
@@ -1391,7 +1391,7 @@ void KoTextEditor::insertBibliography(KoBibliographyInfo *info)
     if (changeTracker && changeTracker->recordChanges()) {
         QTextCharFormat charFormat = d->caret.charFormat();
         QTextBlockFormat blockFormat = d->caret.blockFormat();
-        QString title = i18n("Insert Bibliography");
+        QString title = i18nc("(qtundo-format)", "Insert Bibliography");
 
         int changeId;
         if (!d->caret.atBlockStart()) {
@@ -1496,7 +1496,7 @@ void KoTextEditor::insertText(const QString &text)
     d->caret.setPosition(startPosition);
     d->caret.setPosition(endPosition, QTextCursor::KeepAnchor);
 
-    registerTrackedChange(d->caret, KoGenChange::InsertChange, i18n("Typing"), format, format, false);
+    registerTrackedChange(d->caret, KoGenChange::InsertChange, i18nc("(qtundo-format)", "Typing"), format, format, false);
 
     d->caret.clearSelection();
 
