@@ -711,7 +711,7 @@ static bool compareTab(const QTextOption::Tab &tab1, const QTextOption::Tab &tab
 bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
 {
     QTextBlock block(cursor->it.currentBlock());
-    KoTextBlockData *blockData = dynamic_cast<KoTextBlockData *>(block.userData());
+    KoTextBlockData blockData(block);
     KoParagraphStyle pStyle(block.blockFormat(), block.charFormat());
 
     int dropCapsAffectsNMoreLines = 0;
@@ -766,20 +766,13 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
 
         QFont font(labelFormat.font(), d->documentLayout->paintDevice());
 
-        if (!(blockData && blockData->hasCounterData())) {
+        if (!blockData.hasCounterData()) {
             ListItemsHelper lih(textList, font);
             lih.recalculateBlock(block);
-            blockData = dynamic_cast<KoTextBlockData*>(block.userData());
         }
-        if (blockData) {
-            blockData->setLabelFormat(labelFormat);
-        }
-    } else if (blockData) { // make sure it is empty
-        blockData->clearCounter();
-    }
-    if (blockData == 0) {
-        blockData = new KoTextBlockData();
-        block.setUserData(blockData);
+        blockData.setLabelFormat(labelFormat);
+    } else { // make sure it is empty
+        blockData.clearCounter();
     }
 
     QTextLayout *layout = block.layout();
@@ -863,7 +856,7 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
                     lineHeight = lineRepresentative.charFormat().fontPointSize();
                     qreal linespacing = pStyle.lineSpacing();
                     if (linespacing == 0) { // unset
-                        int percent = pStyle.lineHeightPercent();
+                        qreal percent = pStyle.lineHeightPercent();
                         if (percent != 0)
                             linespacing = lineHeight * ((percent - 100) / 100.0);
                         else if (linespacing == 0)
@@ -952,7 +945,7 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
                 startMargin = listFormat.doubleProperty(KoListStyle::Margin);
             }
 
-            labelBoxWidth = blockData->counterWidth();
+            labelBoxWidth = blockData.counterWidth();
             Qt::Alignment align = static_cast<Qt::Alignment>(listFormat.intProperty(KoListStyle::Alignment));
             if (align == 0) {
                 align = Qt::AlignLeft;
@@ -964,7 +957,7 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
             }
             labelBoxIndent = d->indent - labelBoxWidth;
         } else {
-            labelBoxWidth = blockData->counterSpacing() + blockData->counterWidth();
+            labelBoxWidth = blockData.counterSpacing() + blockData.counterWidth();
         }
     }
 
@@ -988,7 +981,7 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
     // Make a list of tabs that Qt can use
     QList<QTextOption::Tab> qTabs;
     // Note: Converting to Qt tabs is needed as long as we use Qt for layout, but we
-    // loose the posibility to do leader chars.
+    // loose the possibility to do leader chars.
     foreach (KoText::Tab kTab, tabs) {
         qreal value = kTab.position;
         if (value == MaximumTabPos) { // MaximumTabPos is used in index generators
@@ -1149,11 +1142,11 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
             }
             d->width -= listFormat.doubleProperty(KoListStyle::Indent) + minLabelWidth;
             d->indent +=  labelBoxWidth - minLabelWidth;
-            blockData->setCounterPosition(QPointF(d->x + d->indent - labelBoxWidth, d->y));
-        } else if (labelBoxWidth > 0.0 || blockData->counterText().length() > 0) {
-            // Alignmentmode and there is a label (double check needed to acount for both
+            blockData.setCounterPosition(QPointF(d->x + d->indent - labelBoxWidth, d->y));
+        } else if (labelBoxWidth > 0.0 || blockData.counterText().length() > 0) {
+            // Alignmentmode and there is a label (double check needed to account for both
             // picture bullets and non width chars)
-            blockData->setCounterPosition(QPointF(d->x + labelBoxIndent, d->y));
+            blockData.setCounterPosition(QPointF(d->x + labelBoxIndent, d->y));
             if (listFormat.intProperty(KoListStyle::LabelFollowedBy) == KoListStyle::ListTab
                 && !presentationListTabWorkaround(textIndent(block, textList, pStyle), labelBoxWidth, presentationListTabValue)) {
                 foreach(QTextOption::Tab tab, qTabs) {
@@ -1457,13 +1450,13 @@ qreal KoTextLayoutArea::verticalAlignOffset() const
     return d->verticalAlignOffset;
 }
 
-qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBlockData *blockData)
+qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBlockData &blockData)
 {
     QTextBlock block = cursor->it.currentBlock();
     QTextBlockFormat format = block.blockFormat();
     KoParagraphStyle style(format, block.charFormat());
 
-    if (blockData && block.textList() && block.layout()->lineCount() == 1) {
+    if (block.textList() && block.layout()->lineCount() == 1) {
         Qt::Alignment alignment = format.alignment();
         if (d->isRtl && (alignment & Qt::AlignAbsolute) == 0) {
             if (alignment & Qt::AlignLeft) {
@@ -1478,18 +1471,18 @@ qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBl
         qreal newX;
         if (alignment & Qt::AlignHCenter) {
             const qreal padding = (line.width() - line.naturalTextWidth()) / 2;
-            newX = blockData->counterPosition().x() + (d->isRtl ? -padding : padding);
+            newX = blockData.counterPosition().x() + (d->isRtl ? -padding : padding);
         } else if (alignment & Qt::AlignRight) {
             const qreal padding = line.width() - line.naturalTextWidth();
-            newX = blockData->counterPosition().x() + (d->isRtl ? -padding : padding);
+            newX = blockData.counterPosition().x() + (d->isRtl ? -padding : padding);
         } else {
-            newX = blockData->counterPosition().x();
+            newX = blockData.counterPosition().x();
         }
         if (d->isRtl) {
             newX = line.x() + line.naturalTextWidth() + line.x() + d->indent - newX;
         }
 
-        blockData->setCounterPosition(QPointF(newX, blockData->counterPosition().y()));
+        blockData.setCounterPosition(QPointF(newX, blockData.counterPosition().y()));
     }
 
     qreal height = 0;
@@ -1634,7 +1627,7 @@ qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBl
     } else {
         qreal lineSpacing = format.doubleProperty(KoParagraphStyle::LineSpacing);
         if (lineSpacing == 0.0) { // unset
-            int percent = format.intProperty(KoParagraphStyle::PercentLineHeight);
+            qreal percent = format.doubleProperty(KoParagraphStyle::PercentLineHeight);
             if (percent != 0) {
                 height *= percent / 100.0;
             } else {
@@ -1666,10 +1659,10 @@ qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBl
             d->blockRects.last().moveTop(d->blockRects.last().top() + lineAdjust);
         }
 
-        if (blockData && block.textList() && block.layout()->lineCount() == 1) {
+        if (block.textList() && block.layout()->lineCount() == 1) {
             // If this is the first line in a list (aka the first line after the list-
             // item) then we also need to adjust the counter to match to the line again.
-            blockData->setCounterPosition(QPointF(blockData->counterPosition().x(), blockData->counterPosition().y() + lineAdjust));
+            blockData.setCounterPosition(QPointF(blockData.counterPosition().x(), blockData.counterPosition().y() + lineAdjust));
         }
     }
 
@@ -1903,7 +1896,7 @@ void KoTextLayoutArea::clearPreregisteredFootNotes()
     }
 }
 
-void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData *blockData, QTextBlock *block)
+void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData &blockData, QTextBlock *block)
 {
     QTextBlockFormat format = block->blockFormat();
     KoParagraphStyle formatStyle(format, block->charFormat());
@@ -1927,9 +1920,9 @@ void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData *blockData, QText
         x += d->indent;
         width -= d->indent;
     }
-    if (blockData && blockData->hasCounterData() && blockData->counterPosition().x() < x) {
-       width += x - blockData->counterPosition().x();
-       x = blockData->counterPosition().x();
+    if (blockData.hasCounterData() && blockData.counterPosition().x() < x) {
+       width += x - blockData.counterPosition().x();
+       x = blockData.counterPosition().x();
     }
 
     KoTextBlockBorderData border(QRectF(x, d->y, width, 1));
@@ -1948,14 +1941,9 @@ void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData *blockData, QText
     border.setMergeWithNext(formatStyle.joinBorder());
 
     if (border.hasBorders()) {
-        if (blockData == 0) {
-            blockData = new KoTextBlockData();
-            block->setUserData(blockData);
-        }
-
         // check if we can merge with the previous parags border.
         if (d->prevBorder && d->prevBorder->equals(border)) {
-            blockData->setBorder(d->prevBorder);
+            blockData.setBorder(d->prevBorder);
             // Merged mean we don't have inserts inbetween the blocks
             d->anchoringParagraphTop = d->y;
             if (d->bottomSpacing + topMargin) {
@@ -1970,7 +1958,7 @@ void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData *blockData, QText
         } else {
             // can't merge; then these are our new borders.
             KoTextBlockBorderData *newBorder = new KoTextBlockBorderData(border);
-            blockData->setBorder(newBorder);
+            blockData.setBorder(newBorder);
             if (d->prevBorder) {
                 d->y += d->prevBorderPadding;
                 d->y += d->prevBorder->inset(KoTextBlockBorderData::Bottom);
@@ -2003,8 +1991,7 @@ void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData *blockData, QText
             d->y += d->prevBorderPadding;
             d->y += d->prevBorder->inset(KoTextBlockBorderData::Bottom);
         }
-        if (blockData)
-            blockData->setBorder(0); // remove an old one, if there was one.
+        blockData.setBorder(0); // remove an old one, if there was one.
         if (!d->blockRects.isEmpty()) {
             d->blockRects.last().setBottom(d->y);
         }
@@ -2022,10 +2009,10 @@ void KoTextLayoutArea::handleBordersAndSpacing(KoTextBlockData *blockData, QText
         d->width -= format.doubleProperty(KoParagraphStyle::LeftPadding);
         d->width -= format.doubleProperty(KoParagraphStyle::RightPadding);
     }
-    if (block->layout()->lineCount() == 1 && blockData && blockData->hasCounterData()) {
-        blockData->setCounterPosition(QPointF(blockData->counterPosition().x() + dx, d->y));
+    if (block->layout()->lineCount() == 1 && blockData.hasCounterData()) {
+        blockData.setCounterPosition(QPointF(blockData.counterPosition().x() + dx, d->y));
     }
-    d->prevBorder = blockData->border();
+    d->prevBorder = blockData.border();
     d->prevBorderPadding = format.doubleProperty(KoParagraphStyle::BottomPadding);
     d->anchoringParagraphContentTop = d->y;
 }
