@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 - 2011 Dag Andersen <danders@get2net.dk>
+   Copyright (C) 2003 - 2011, 2012 Dag Andersen <danders@get2net.dk>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,25 +23,28 @@
 #include "kptresource.h"
 #include "kptcalendar.h"
 #include "kptresourcemodel.h"
+#include "kptdebug.h"
 
 #include <QPushButton>
 #include <QList>
-#include <qstringlist.h>
+#include <QStringList>
 #include <QSortFilterProxyModel>
 #include <QStandardItem>
 
 #include <kdeversion.h>
+#ifdef PLAN_KDEPIMLIBS_FOUND
 #if KDE_IS_VERSION( 4, 5, 0 )
 #include <akonadi/contact/emailaddressselectiondialog.h>
 #include <akonadi/contact/emailaddressselectionwidget.h>
 #include <akonadi/contact/emailaddressselection.h>
 #endif
+#endif
 
 #include <kdatetimewidget.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kglobal.h>
-#include <kdebug.h>
+
 
 namespace KPlato
 {
@@ -52,6 +55,10 @@ ResourceDialogImpl::ResourceDialogImpl( const Project &project, Resource &resour
     m_resource( resource )
 {
     setupUi(this);
+
+#ifndef PLAN_KDEPIMLIBS_FOUND
+    chooseBtn->hide();
+#endif
 #if ! KDE_IS_VERSION( 4, 5, 0 )
     chooseBtn->hide();
 #endif
@@ -68,7 +75,7 @@ ResourceDialogImpl::ResourceDialogImpl( const Project &project, Resource &resour
         QList<QStandardItem *> items;
         QStandardItem *item = new QStandardItem( r->name() );
         item->setCheckable( true );
-        item->setCheckState( m_resource.teamMembers().contains( r ) ? Qt::Checked : Qt::Unchecked );
+        item->setCheckState( m_resource.teamMemberIds().contains( r->id() ) ? Qt::Checked : Qt::Unchecked );
         items << item;
         item = new QStandardItem( r->parentGroup()->name() );
         items << item;
@@ -128,20 +135,32 @@ void ResourceDialogImpl::slotTeamChanged( const QModelIndex &index ) {
     bool checked = (bool)(index.data( Qt::CheckStateRole ).toInt());
     int idCol = index.model()->columnCount() - 1;
     QString id = index.model()->index( index.row(), idCol ).data().toString();
-    Resource *r = m_project.findResource( id );
-    Q_ASSERT( r );
     if ( checked ) {
-        if ( ! m_resource.teamMembers().contains( r ) ) {
-            m_resource.addTeamMember( r );
+        if ( ! m_resource.teamMemberIds().contains( id ) ) {
+            m_resource.addTeamMemberId( id );
         }
     } else {
-        m_resource.removeTeamMember( r );
+        m_resource.removeTeamMemberId( id );
     }
     emit changed();
 }
 
 void ResourceDialogImpl::slotTypeChanged( int index ) {
-    ui_stackedWidget->setCurrentIndex( index == Resource::Type_Team ? 1 : 0 );
+    switch ( index ) {
+        case Resource::Type_Work:
+            ui_stackedWidget->setCurrentIndex( 0 );
+            useRequired->setEnabled( true );
+            slotUseRequiredChanged( useRequired->checkState() );
+            break;
+        case Resource::Type_Material:
+            ui_stackedWidget->setCurrentIndex( 0 );
+            useRequired->setEnabled( false );
+            slotUseRequiredChanged( false );
+            break;
+        case Resource::Type_Team:
+            ui_stackedWidget->setCurrentIndex( 1 );
+            break;
+    }
     emit changed();
 }
 
@@ -177,7 +196,7 @@ void ResourceDialogImpl::slotUseRequiredChanged( int state )
 void ResourceDialogImpl::slotAvailableFromChanged(const QDateTime&) {
     if (availableUntil->dateTime() < availableFrom->dateTime()) {
         disconnect(availableUntil, SIGNAL(dateTimeChanged(const QDateTime&)), this,  SLOT(slotAvailableUntilChanged(const QDateTime&)));
-        //kDebug()<<"From:"<<availableFrom->dateTime().toString()<<" until="<<availableUntil->dateTime().toString();
+        //kDebug(planDbg())<<"From:"<<availableFrom->dateTime().toString()<<" until="<<availableUntil->dateTime().toString();
         availableUntil->setDateTime(availableFrom->dateTime());
         connect(availableUntil, SIGNAL(dateTimeChanged(const QDateTime&)), SLOT(slotAvailableUntilChanged(const QDateTime&)));
     }
@@ -186,7 +205,7 @@ void ResourceDialogImpl::slotAvailableFromChanged(const QDateTime&) {
 void ResourceDialogImpl::slotAvailableUntilChanged(const QDateTime&) {
     if (availableFrom->dateTime() > availableUntil->dateTime()) {
         disconnect(availableFrom, SIGNAL(dateTimeChanged(const QDateTime&)), this,  SLOT(slotAvailableFromChanged(const QDateTime&)));
-        //kDebug()<<"Until:"<<availableUntil->dateTime().toString()<<" from="<<availableFrom->dateTime().toString();
+        //kDebug(planDbg())<<"Until:"<<availableUntil->dateTime().toString()<<" from="<<availableFrom->dateTime().toString();
         availableFrom->setDateTime(availableUntil->dateTime());
         connect(availableFrom, SIGNAL(dateTimeChanged(const QDateTime&)), SLOT(slotAvailableFromChanged(const QDateTime&)));
     }
@@ -199,6 +218,7 @@ void ResourceDialogImpl::slotCalculationNeeded(const QString&) {
 
 void ResourceDialogImpl::slotChooseResource()
 {
+#ifdef PLAN_KDEPIMLIBS_FOUND
 #if KDE_IS_VERSION( 4, 5, 0 )
     QPointer<Akonadi::EmailAddressSelectionDialog> dlg = new Akonadi::EmailAddressSelectionDialog( this );
     if ( dlg->exec() && dlg ) {
@@ -218,6 +238,7 @@ void ResourceDialogImpl::slotChooseResource()
         }
     }
 #endif
+#endif
 }
 
 //////////////////  ResourceDialog  ////////////////////////
@@ -356,12 +377,12 @@ void ResourceDialog::slotOk() {
     m_resource.setAvailableFrom( dia->ui_rbfrom->isChecked() ? dia->availableFrom->dateTime() : QDateTime() );
     m_resource.setAvailableUntil( dia->ui_rbuntil->isChecked() ? dia->availableUntil->dateTime() : QDateTime() );
     ResourceItemSFModel *m = static_cast<ResourceItemSFModel*>( dia->required->model() );
-    QList<Resource*> lst;
+    QStringList lst;
     foreach ( const QModelIndex &i, dia->required->currentIndexes() ) {
         Resource *r = m->resource( i );
-        if ( r ) lst << r;
+        if ( r ) lst << r->id();
     }
-    m_resource.setRequiredResources( lst );
+    m_resource.setRequiredIds( lst );
     accept();
 }
 
@@ -426,28 +447,26 @@ MacroCommand *ResourceDialog::buildCommand(Resource *original, Resource &resourc
         if (!m) m = new MacroCommand(n);
         m->addCommand(new ModifyResourceCalendarCmd(original, resource.calendar(true)));
     }
-    if (resource.requiredResources() != original->requiredResources()) {
+    if (resource.requiredIds() != original->requiredIds()) {
         if (!m) m = new MacroCommand(n);
-        m->addCommand(new ModifyRequiredResourcesCmd(original, resource.requiredResources()));
+        m->addCommand(new ModifyRequiredResourcesCmd(original, resource.requiredIds()));
     }
     if (resource.account() != original->account()) {
         if (!m) m = new MacroCommand(n);
         m->addCommand(new ResourceModifyAccountCmd(*original, original->account(), resource.account()));
     }
     if ( resource.type() == Resource::Type_Team ) {
-        //kDebug()<<original->teamMembers()<<resource.teamMembers();
-        foreach ( Resource *r, resource.teamMembers() ) {
-            if ( ! original->teamMembers().contains( r ) ) {
+        //kDebug(planDbg())<<original->teamMembers()<<resource.teamMembers();
+        foreach ( const QString &id, resource.teamMemberIds() ) {
+            if ( ! original->teamMemberIds().contains( id ) ) {
                 if (!m) m = new MacroCommand(n);
-                m->addCommand( new AddResourceTeamCmd( original, r ) );
-                //kDebug()<<original->name()<<"added member"<<r->name();
+                m->addCommand( new AddResourceTeamCmd( original, id ) );
             }
         }
-        foreach ( Resource *r, original->teamMembers() ) {
-            if ( ! resource.teamMembers().contains( r ) ) {
+        foreach ( const QString &id, original->teamMemberIds() ) {
+            if ( ! resource.teamMemberIds().contains( id ) ) {
                 if (!m) m = new MacroCommand(n);
-                m->addCommand( new RemoveResourceTeamCmd( original, r ) );
-                //kDebug()<<original->name()<<"removed member"<<r->name();
+                m->addCommand( new RemoveResourceTeamCmd( original, id ) );
             }
         }
     }
