@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
  * Copyright (C) 2007 Fredy Yanardi <fyanardi@gmail.com>
  * Copyright (C) 2011 Boudewijn Rempt <boud@valdyas.org>
+ * Copyright (C) 2012 Shreya Pandit <shreya@shreyapandit.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,11 +22,23 @@
 #ifndef KWSTATISTICSDOCKER_H
 #define KWSTATISTICSDOCKER_H
 
+// Base classes
 #include <QDockWidget>
-#include <KoDockFactoryBase.h>
 #include <KoCanvasObserverBase.h>
+
+// Qt
+#include <QBoxLayout>
+#include <QGridLayout>
+
+// Calligra
+#include <KoDockFactoryBase.h>
+
+// Local
+#include <dockers/KWStatisticsWidget.h>
+
 class KoCanvasBase;
 
+
 class KWStatisticsDocker : public QDockWidget, public KoCanvasObserverBase
 {
     Q_OBJECT
@@ -33,20 +46,38 @@ class KWStatisticsDocker : public QDockWidget, public KoCanvasObserverBase
 public:
     explicit KWStatisticsDocker();
     ~KWStatisticsDocker();
-
+    void initLayout();
     /// reimplemented from KoCanvasObserver
     virtual void setCanvas(KoCanvasBase *canvas);
     virtual void unsetCanvas();
 
 private:
     bool m_canvasReset;
+
+    // The statistics widget
+    KWStatisticsWidget *m_statisticsWidget;
+
+    // The main layout
+    QBoxLayout *m_mainBox;
+
+    // The layouts for the label/value QLabel pairs.
+    QHBoxLayout *m_wordsLayout;
+    QHBoxLayout *m_sentencesLayout;
+    QHBoxLayout *m_syllablesLayout;
+    QHBoxLayout *m_spacesLayout;
+    QHBoxLayout *m_fleschLayout;
+    QHBoxLayout *m_cjkcharsLayout;
+    QHBoxLayout *m_nospacesLayout;
+    QHBoxLayout *m_linesLayout;
+    
+public slots:
+    void ondockLocationChanged(Qt::DockWidgetArea newArea);
 };
 
 class KWStatisticsDockerFactory : public KoDockFactoryBase
 {
 public:
     KWStatisticsDockerFactory();
-
     virtual QString id() const;
     virtual QDockWidget* createDockWidget();
     DockPosition defaultDockPosition() const {
